#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *Scrollbar.width 10
	}
    }
    
}
############################
# vTcl Code to Load Stock Fonts


if {![info exist vTcl(sourcing)]} {
set vTcl(fonts,counter) 0
proc vTcl:font:add_font {font_descr font_type newkey} {
     global vTcl

     incr vTcl(fonts,counter)
     set newfont [eval font create $font_descr]

     lappend vTcl(fonts,objects) $newfont

     # each font has its unique key so that when a project is
     # reloaded, the key is used to find the font description

     if {$newkey == ""} {
          set newkey vTcl:font$vTcl(fonts,counter)

          # let's find an unused font key
          while {[vTcl:font:get_font $newkey] != ""} {
             incr vTcl(fonts,counter)
             set newkey vTcl:font$vTcl(fonts,counter)
          }
     }

     set vTcl(fonts,$newfont,type)                      $font_type
     set vTcl(fonts,$newfont,key)                       $newkey
     set vTcl(fonts,$vTcl(fonts,$newfont,key),object)   $newfont

     lappend vTcl(fonts,$font_type) $newfont

     # in case caller needs it
     return $newfont
}

proc vTcl:font:get_font {key} {
    global vTcl
    if {[info exists vTcl(fonts,$key,object)]} then {
        return $vTcl(fonts,$key,object)
    } else {
        return ""
    }
}

vTcl:font:add_font \
    "-family helvetica -size 12 -weight bold -slant roman -underline 0 -overstrike 0" \
    stock \
    vTcl:font5
}
############################
# vTcl Code to Load User Fonts

vTcl:font:add_font \
    "-family {Comic Sans MS} -size 8 -weight normal -slant roman -underline 0 -overstrike 0" \
    user \
    vTcl:font13
vTcl:font:add_font \
    "-family {Courier New Tur} -size 8 -weight normal -slant roman -underline 0 -overstrike 0" \
    user \
    vTcl:font19
vTcl:font:add_font \
    "-family {Arial Black} -size 20 -weight normal -slant roman -underline 0 -overstrike 0" \
    user \
    vTcl:font18
vTcl:font:add_font \
    "-family {Arial Tur} -size 9 -weight normal -slant roman -underline 0 -overstrike 0" \
    user \
    vTcl:font20
#############################################################################
# Visual Tcl v1.51 Project
#

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
proc Window {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}

proc vTcl:WindowsCleanup {} {
    global vTcl
    if {[info exists vTcl(sourcing)]} { return }
    foreach w [winfo children .] {
    	wm protocol $w WM_DELETE_WINDOW { exit }
    }
}
}

if {![info exists vTcl(sourcing)]} {
proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget

    set widget($alias) $target
    set widget(rev,$target) $alias

    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }

    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target

        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}

proc {vTcl:DoCmdOption} {target cmd} {
    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}

proc {vTcl:FireEvent} {target event} {
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                regsub -all %W $bind_code $target bind_code
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    # break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    switch -- $command {
        "hide" -
        "Hide" {
            Window hide $w
        }

        "show" -
        "Show" {
            Window show $w
        }

        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }

        default {
            eval $w $command $args
        }
    }
}

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    eval $w $command $args
}

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}

if {[info exists vTcl(sourcing)]} {
proc vTcl:project:info {} {
    namespace eval ::widgets::.top31 {
        array set save {-menu 1 -relief 1}
    }
    namespace eval ::widgets::.top31.but34 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.m23 {
        array set save {-activeborderwidth 1 -borderwidth 1 -tearoff 1}
    }
    namespace eval ::widgets::.top31.m41 {
        array set save {-activeborderwidth 1 -borderwidth 1 -tearoff 1}
    }
    namespace eval ::widgets::.top31.m40 {
        array set save {-activeborderwidth 1 -borderwidth 1 -font 1 -tearoff 1}
    }
    namespace eval ::widgets::.top31.but43 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.ent40 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.ent41 {
        array set save {-background 1 -cursor 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab44 {
        array set save {-font 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab45 {
        array set save {-font 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab46 {
        array set save {-font 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top31.lab51 {
        array set save {-font 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab54 {
        array set save {-font 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61.rad62 {
        array set save {-command 1 -font 1 -text 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::.top31.fra61.but69 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61.ent70 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61.lis40 {
        array set save {-background 1 -foreground 1 -height 1 -listvariable 1 -relief 1 -width 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top31.fra61.but43 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top31.fra61.but44 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61.but40 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra61.scr42 {
        array set save {-command 1}
    }
    namespace eval ::widgets::.top31.fra65 {
        array set save {-borderwidth 1 -cursor 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra65.rad66 {
        array set save {-command 1 -font 1 -height 1 -text 1 -value 1 -variable 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra65.ent67 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra65.ent68 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.fra65.lab71 {
        array set save {-font 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top31.fra65.lab72 {
        array set save {-text 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab73 {
        array set save {-activebackground 1 -anchor 1 -background 1 -borderwidth 1 -font 1 -foreground 1 -height 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.but75 {
        array set save {-command 1 -font 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.ent78 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab81 {
        array set save {-font 1 -foreground 1 -height 1 -highlightcolor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab82 {
        array set save {-font 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.mes48 {
        array set save {-font 1 -padx 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top31.ent54 {
        array set save {-background 1 -font 1 -foreground 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top31.lab55 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top50 {
        array set save {-relief 1}
    }
    namespace eval ::widgets::.top50.mes51 {
        array set save {-background 1 -font 1 -foreground 1 -padx 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top50.mes52 {
        array set save {-background 1 -font 1 -foreground 1 -padx 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top50.but54 {
        array set save {-command 1 -height 1 -pady 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top50.mes40 {
        array set save {-background 1 -foreground 1 -padx 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {}
    }
}
}
#################################
# USER DEFINED PROCEDURES
#
###########################################################
## Procedure:  init
###########################################################
## Procedure:  main

proc {main} {argc argv} {
wm protocol .top31 WM_DELETE_WINDOW {exit}
}

proc init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base {container 0}} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    wm focusmodel $base passive
    wm geometry $base 200x200+26+26; update
    wm maxsize $base 1028 749
    wm minsize $base 132 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vtcl"
    bindtags $base "$base Vtcl all"
    vTcl:FireEvent $base <<Create>>
    }
    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top31 {base {container 0}} {
    if {$base == ""} {
        set base .top31
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "ana" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but34" "Button2" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.but43" "Button10" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.but75" "Button4" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.ent40" "Entry1" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.ent41" "Entry2" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.ent54" "Entry10" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.ent78" "Entry9" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61" "Frame4" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.but40" "Button13" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.but43" "Button14" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.but44" "Button15" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.but69" "Button9" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.ent70" "Entry8" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.lis40" "Listbox1" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.rad62" "Radiobutton3" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra61.scr42" "Scrollbar1" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65" "Frame5" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65.ent67" "Entry6" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65.ent68" "Entry7" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65.lab71" "Label19" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65.lab72" "Label20" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.fra65.rad66" "Radiobutton4" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab44" "Label7" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab45" "Label8" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab46" "Label9" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab51" "Label12" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab54" "Label14" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab55" "Label30" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab73" "Label17" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab81" "Label22" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.lab82" "Label23" vTcl:WidgetProc "ana" 1
    vTcl:DefineAlias "$base.mes48" "Message8" vTcl:WidgetProc "ana" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m40" -relief groove 
    wm focusmodel $base passive
    wm geometry $base 611x366+136+124; update
    wm maxsize $base 611 366
    wm minsize $base 134 2
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "Testere 1.2"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but34 \
        \
        -command load\ crypt10.dll\n\ \ \ \ \nproc\ sozlukten\ \{\}\ \{\nglobal\ filename\nglobal\ mode\nglobal\ ksayi\ \nglobal\ alg\nglobal\ sifre\nglobal\ sifrele\nglobal\ ekran\nglobal\ oku\nglobal\ satir\nset\ filename\ \[Listbox1\ get\ active\]\nset\ sozluk\ \[open\ \$filename\]\nfconfigure\ \$sozluk\ -blocking\ no\nwhile\ \{\[eof\ \$sozluk\]\ <\ 1\}\ \{\nset\ oku\ \[gets\ \$sozluk\]\nset\ sifrele\ \[crypt\ \$oku\ \$alg\]\nset\ ekran\ \"\$oku\"\nif\ \{\$sifre\ ==\ \$sifrele\}\ \{set\ ekran\ \"\$oku\"\;close\ \$sozluk\;break\}\ else\ \{\}\nupdate\n\}\n\}\nproc\ rakamdan\ \{\}\ \{\nglobal\ mode\nglobal\ rakam1\nglobal\ rakam2\nglobal\ alg\nglobal\ sifre\nglobal\ sifrele\nglobal\ ekran\nfor\ \{\}\ \{\$rakam1\ <\ \$rakam2\ \}\ \{incr\ rakam1\;\}\ \{\nset\ sifrele\ \[crypt\ \$rakam1\ \$alg\]\nset\ ekran\ \"\$rakam1\"\nif\ \{\$sifre\ ==\ \$sifrele\}\ \{set\ ekran\ \"\$rakam1\"\;set\ rakam1\ \"\"\;break\}\ else\ \{\ \}\nupdate\n\}\n\}\n\nswitch\ \$kullan\ \\\n\ \ \ \ \"sozlukkullan\"\ \"sozlukten\"\ \\\n\ \ \ \ \"rakamkullan\"\ \"rakamdan\"\ \\\n\n#set\ ekran\ \"ifre\ Bulunamad\"\n\n#close\ \$sozluk\n#set\ ekran\ \"ifre\ Krlamad\" \
        -font [vTcl:font:get_font "vTcl:font13"] -height 26 -pady 0 \
        -relief groove -text Dekript -width 94 
    menu $base.m23 \
        -activeborderwidth 1 -borderwidth 1 -tearoff 1 
    menu $base.m41 \
        -activeborderwidth 1 -borderwidth 1 -tearoff 1 
    menu $base.m40 \
        -activeborderwidth 1 -borderwidth 1 -font {{MS Sans Serif} 10} \
        -tearoff 1 
    button $base.but43 \
        -command {about show} -font [vTcl:font:get_font "vTcl:font13"] \
        -height 26 -pady 0 -relief groove -text Hakknda -width 81 
    entry $base.ent40 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable sifre -width 126 
    entry $base.ent41 \
        -background #000000 -cursor xterm \
        -font [vTcl:font:get_font "vTcl:font13"] -foreground #00ff40 \
        -relief groove -textvariable alg -width 26 
    label $base.lab44 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 -text {Text :} \
        -width 31 
    label $base.lab45 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 \
        -text {Algoritma (2 Karakter) :} -width 128 
    label $base.lab46 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 -text {Kript :} 
    label $base.lab51 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 \
        -text {Dekript Modu :} -width 79 
    label $base.lab54 \
        -font [vTcl:font:get_font "vTcl:font19"] -height 0 \
        -text {Testere 1.2 by Ironic    ironichack@yahoo.com} -width 363 
    frame $base.fra61 \
        -borderwidth 2 -height 210 -relief groove -width 265 
    radiobutton $base.fra61.rad62 \
        -command {set kullan "sozlukkullan"
set mode "Szlk Kullanarak"} \
        -font [vTcl:font:get_font "vTcl:font13"] -text {Szlk kullan} \
        -value 0 -variable "$base\::selectedButton" 
    button $base.fra61.but69 \
        \
        -command [list vTcl:DoCmdOption $base.fra61.but69 {proc {dosyaac} {mainw {file {}}} {
global filename widget tk_strictMotif

    if {$file == ""} {
        set old $tk_strictMotif
        set tk_strictMotif 0
	set file [tk_getOpenFile  -defaultextension {.txt}   -initialdir .  -filetypes {{{Text Dosya} *.txt} {all *.*} }  -initialfile $filename  -title "Dosya A.."]
        set tk_strictMotif $old
    }

    if {$file == ""} {return}

    ## starts new empty document, then load the file
    
    #set filename $file
    Listbox1 insert end $file
    #set id [open $filename]
    #set ttd [read $id]
    #close $id
    
        
}

dosyaac %1}] \
        -font [vTcl:font:get_font "vTcl:font13"] -height 23 -pady 0 \
        -relief groove -text {Szlk A} -width 70 
    entry $base.fra61.ent70 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable filename -width 221 
    listbox $base.fra61.lis40 \
        -background #000000 -foreground #00ff40 -height 91 -relief groove \
        -width 228 -yscrollcommand {Scrollbar1 set} -listvariable sozlukoku 
    bind $base.fra61.lis40 <ButtonRelease-2> {
        # TODO: your event handler here
Listbox1 delete active
    }
    bind $base.fra61.lis40 <Key-Delete> {
        # TODO: your event handler here
Listbox1 delete active
    }
    button $base.fra61.but43 \
        \
        -command {file delete sozluk.cfg
set sozayar [Listbox1 get 0 end]
set ayardosya [open sozluk.cfg a+]
seek $ayardosya 0 start
puts $ayardosya $sozayar
close $ayardosya} \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 -pady 0 \
        -relief groove -text {Sozluk Ayarlarn Kaydet} 
    button $base.fra61.but44 \
        \
        -command {set sozlukler [open sozluk.cfg]
set sozlukoku [read $sozlukler]
close $sozlukler} \
        -font [vTcl:font:get_font "vTcl:font13"] -height 23 -pady 0 \
        -relief groove -text Szlkler -width 64 
    button $base.fra61.but40 \
        -command {Listbox1 delete 0 end} \
        -font [vTcl:font:get_font "vTcl:font13"] -height 25 -pady 0 \
        -relief groove -text {Listeyi sil} -width 85 
    scrollbar $base.fra61.scr42 \
        -command {Listbox1 yview} 
    frame $base.fra65 \
        -borderwidth 2 -cursor fleur -height 55 -relief groove -width 265 
    radiobutton $base.fra65.rad66 \
        -command {set kullan "rakamkullan"
set mode "Rakam Kullanarak"} \
        -font [vTcl:font:get_font "vTcl:font13"] -height 22 \
        -text {Rakam kullan} -value 1 -variable "$base\::selectedButton" \
        -width 98 
    entry $base.fra65.ent67 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable rakam1 -width 57 
    entry $base.fra65.ent68 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable rakam2 -width 67 
    label $base.fra65.lab71 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 \
        -text {Rakam Aral :} 
    label $base.fra65.lab72 \
        -text __ -width 19 
    label $base.lab73 \
        -activebackground #000000 -anchor nw -background #000000 \
        -borderwidth 1 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -height 0 -relief groove -text { } \
        -textvariable mode -width 145 
    button $base.but75 \
        -command {load crypt10.dll
set sifreout [crypt $sifre $alg]} \
        -font [vTcl:font:get_font "vTcl:font13"] -height 24 -pady 0 \
        -relief groove -text Kript -width 95 
    entry $base.ent78 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable sifreout -width 151 
    label $base.lab81 \
        -font [vTcl:font:get_font "vTcl:font18"] -foreground #808080 \
        -height 0 -highlightcolor #000000 -text {Testere 1.2} -width 181 
    label $base.lab82 \
        -font [vTcl:font:get_font "vTcl:font13"] -height 0 \
        -text {DES password encrypter/decrypter} -width 187 
    message $base.mes48 \
        -font [vTcl:font:get_font "vTcl:font20"] -padx 5 -pady 2 \
        -relief sunken \
        -text {Testere 1.2 Kullanm Klavuzu

ifreleme veya Krmak istediiniz metini Text blmne yaznz.

ifrelemek iin Kript tuuna, ifreyi krmak iin Szlk veya Rakam opsiyonlarn seerek Dekript tuuna basnz.

Algoritma ksmna krmak istediiniz metinin ilk 2 karakterini yaznz.

Uyar :Turbo Dekript zelliinden dolay dekript yaparken program kilitlenme yapabiliyor.Bu durumda herey yolundadr, program kapatmaya almayn..} \
        -width 321 
    entry $base.ent54 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -relief groove -textvariable ekran -width 1078 
    label $base.lab55 \
        -height 0 -text {Bulunan ifre :} -width 0 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but34 \
        -x 340 -y 285 -width 94 -height 25 -anchor nw -bordermode ignore 
    place $base.but43 \
        -x 225 -y 285 -width 94 -height 25 -anchor nw -bordermode ignore 
    place $base.ent40 \
        -x 45 -y 10 -width 126 -height 19 -anchor nw -bordermode ignore 
    place $base.ent41 \
        -x 305 -y 10 -width 26 -height 19 -anchor nw -bordermode ignore 
    place $base.lab44 \
        -x 10 -y 10 -width 31 -height 21 -anchor nw -bordermode ignore 
    place $base.lab45 \
        -x 175 -y 10 -width 128 -height 21 -anchor nw -bordermode ignore 
    place $base.lab46 \
        -x 135 -y 40 -anchor nw -bordermode ignore 
    place $base.lab51 \
        -x 480 -y 270 -width 79 -height 19 -anchor nw -bordermode ignore 
    place $base.lab54 \
        -x 130 -y 350 -width 363 -height 15 -anchor nw -bordermode ignore 
    place $base.fra61 \
        -x 340 -y 5 -width 265 -height 210 -anchor nw -bordermode ignore 
    place $base.fra61.rad62 \
        -x 10 -y 0 -anchor nw 
    place $base.fra61.but69 \
        -x 10 -y 25 -width 94 -height 25 -anchor nw 
    place $base.fra61.ent70 \
        -x 12 -y 150 -width 221 -height 19 -anchor nw -bordermode ignore 
    place $base.fra61.lis40 \
        -x 10 -y 55 -width 228 -height 91 -anchor nw -bordermode ignore 
    place $base.fra61.but43 \
        -x 10 -y 175 -height 25 -anchor nw -bordermode ignore 
    place $base.fra61.but44 \
        -x 155 -y 27 -width 94 -height 25 -anchor nw -bordermode ignore 
    place $base.fra61.but40 \
        -x 155 -y 173 -width 94 -height 25 -anchor nw 
    place $base.fra61.scr42 \
        -x 235 -y 55 -width 18 -height 91 -anchor nw 
    place $base.fra65 \
        -x 340 -y 220 -width 265 -height 55 -anchor nw -bordermode ignore 
    place $base.fra65.rad66 \
        -x 10 -y 0 -width 98 -height 22 -anchor nw 
    place $base.fra65.ent67 \
        -x 95 -y 25 -width 57 -height 19 -anchor nw 
    place $base.fra65.ent68 \
        -x 190 -y 25 -width 57 -height 19 -anchor nw 
    place $base.fra65.lab71 \
        -x 10 -y 25 -anchor nw -bordermode ignore 
    place $base.fra65.lab72 \
        -x 160 -y 25 -width 19 -height 14 -anchor nw -bordermode ignore 
    place $base.lab73 \
        -x 450 -y 290 -width 145 -height 18 -anchor nw 
    place $base.but75 \
        -x 10 -y 40 -width 94 -height 25 -anchor nw 
    place $base.ent78 \
        -x 185 -y 40 -width 146 -height 19 -anchor nw -bordermode ignore 
    place $base.lab81 \
        -x 10 -y 285 -width 181 -height 26 -anchor nw -bordermode ignore 
    place $base.lab82 \
        -x 10 -y 315 -width 187 -height 14 -anchor nw -bordermode ignore 
    place $base.mes48 \
        -x 10 -y 70 -width 321 -height 211 -anchor nw -bordermode ignore 
    place $base.ent54 \
        -x 450 -y 320 -width 146 -height 21 -anchor nw 
    place $base.lab55 \
        -x 360 -y 321 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top50 {base {container 0}} {
    if {$base == ""} {
        set base .top50
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "about" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but54" "Button7" vTcl:WidgetProc "about" 1
    vTcl:DefineAlias "$base.mes40" "Message7" vTcl:WidgetProc "about" 1
    vTcl:DefineAlias "$base.mes51" "Message4" vTcl:WidgetProc "about" 1
    vTcl:DefineAlias "$base.mes52" "Message5" vTcl:WidgetProc "about" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -relief groove 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 286x224+195+287; update
    wm maxsize $base 1028 753
    wm minsize $base 134 2
    wm overrideredirect $base 0
    wm resizable $base 0 0
    wm title $base "Hakknda"
    vTcl:FireEvent $base <<Create>>
    }
    message $base.mes51 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font13"] \
        -foreground #00ff40 -padx 5 -pady 2 \
        -text {Testere DES Password Encrypter/Decrypter v1.2 

DES Algoritmas ile ifreleme yapar,ifrelenmi metinleri szlk ve rakam kullanarak krar.} \
        -width 261 
    message $base.mes52 \
        -background #000000 -font [vTcl:font:get_font "vTcl:font5"] \
        -foreground #00ff40 -padx 5 -pady 2 \
        -text {Hazrlayan Ironic 
ironichack@yahoo.com
2002} -width 261 
    button $base.but54 \
        -command {about hide} -height 26 -pady 0 -relief groove -text Tamam \
        -width 70 
    message $base.mes40 \
        -background #000000 -foreground #00ff40 -padx 5 -pady 2 \
        -text {http://www.hackrosoft.org.tr.tc
} -width 261 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.mes51 \
        -x 15 -y 5 -width 261 -height 91 -anchor nw -bordermode ignore 
    place $base.mes52 \
        -x 15 -y 95 -width 261 -height 56 -anchor nw -bordermode ignore 
    place $base.but54 \
        -x 105 -y 195 -width 70 -height 26 -anchor nw -bordermode ignore 
    place $base.mes40 \
        -x 15 -y 150 -width 261 -height 41 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

Window show .
Window show .top31
Window show .top50

main $argc $argv
